package com.gic.cloud.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.cloud.web.constant.StoreChannelEnum;
import com.gic.cloud.web.qo.BaseSalesParamQo;
import com.gic.cloud.web.qo.DateTypeQo;
import com.gic.cloud.web.utils.LevelUtil;
import com.gic.cloud.web.vo.BaseSalesVo;
import com.gic.cloud.web.vo.LevelVo;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.data.api.dto.BaseSalesDTO;
import com.gic.data.api.dto.BaseSalesParamsDTO;
import com.gic.data.api.service.BaseSalesApiService;
import com.gic.enterprise.dto.WmStoreDTO;
import com.gic.enterprise.service.WmStoreApiService;
import com.gic.mall.share.api.dto.shop.ShopDTO;
import com.gic.mall.share.api.enums.ShopTypeEnum;
import com.gic.mall.share.api.service.ShopApiService;
import com.google.inject.internal.asm.$Handle;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
public class BaseSalesController {
    private Logger log = LogManager.getLogger(BaseSalesController.class);
    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private StoreSearchUtils storeSearchUtils;
    @Autowired
    private BaseSalesApiService baseSalesApiService;
    @Autowired
    private GoDownComponent goDownComponent;

    @RequestMapping("base-sales")
    public RestResponse baseSales(BaseSalesParamQo qo){
        BaseSalesVo vo = new BaseSalesVo();
        List<Integer> list = this.storeSearchUtils.storeSearch(qo.getUserId(), qo.getEnterpriseId(), qo.getSearchJSON());
        List<String> onLine = this.storeSearchUtils.onLineStoreSearch(qo.getUserId(), qo.getEnterpriseId(), qo.getSearchJSON());
        List<Integer> childrenStoreGroupIdList = this.storeSearchUtils.getChildrenStoreGroupIdList(qo.getParentId());
        List<Long> mbrAreaIdList = this.dataAuthUtils.getMbrAreaId(qo.getUserId(), qo.getEnterpriseId());
        Integer maxLevel = 0;
        /******线下渠道需要点击下钻，该值只会在线下时才会使用********/
        LevelVo levelVo = this.storeSearchUtils.getLevel(qo.getUserId(), qo.getEnterpriseId(), qo.getSearchJSON());
        maxLevel = levelVo.getMaxLevel();
        if(qo.getLevel() == null){
            qo.setLevel(levelVo.getLevel());
        }
        /****首页进入基础页面时，如果渠道为空，根据当前条件判断渠道，channel==null表示多渠道***/
        if(qo.getChannel() == null){
            /**********设置层级名称，只有在首次进入页面会展示，下钻均显示返回上一级*********/
            Integer newChannel = this.storeSearchUtils.getChannel(qo.getUserId(), qo.getEnterpriseId(), qo.getSearchJSON());
            qo.setChannel(newChannel);
        }
        /***********如果是线下的第一层级，需要展示切换层级按钮*************/
        if(qo.getChannel() == StoreChannelEnum.OFFLINE.getChannel() && qo.getLevel() == levelVo.getLevel()){
            vo.setChangeLevel(1);
        }
        if(qo.getChannel() == null){
            vo.setLevelName("所有渠道");
        } else if(qo.getChannel() == StoreChannelEnum.OFFLINE.getChannel()){
            vo.setLevelName(LevelUtil.getLevelName(qo.getLevel()));
        } else {
            vo.setLevelName("店铺层级");
        }
        BaseSalesParamsDTO dto = new BaseSalesParamsDTO();
        dto.setChannel(qo.getChannel());
        dto.setEnterpriseId(qo.getEnterpriseId());
        dto.setStoreInfoIdList(list);
        dto.setOnLine(onLine);
        dto.setMbrAreaId(StringUtils.isBlank(qo.getMbrAreaId()) ? null : Long.valueOf(qo.getMbrAreaId()));
        dto.setMbrAreaIdList(mbrAreaIdList);
        dto.setType(qo.getType());
        dto.setDate(qo.getDate());
        dto.setChildrenStoreGroupIdList(childrenStoreGroupIdList);
        dto.setLevel(qo.getLevel());
        dto.setSortField(qo.getSortField());
        dto.setSortType(qo.getSortType() == null ? 1 : qo.getSortType());
        dto.setPageNum(qo.getPageNum());
        dto.setPageSize(qo.getPageSize());
        ServiceResponse<Page<BaseSalesDTO>> response = this.baseSalesApiService.pageBaseSales(dto);
        log.info("response:{}", JSON.toJSONString(response));
        vo.setPage(this.goDownComponent.parseData(response.getResult(), qo.getChannel(), qo.getEnterpriseId(), qo.getLevel(), maxLevel));
        dto.setCountType(2);//合计
        /**所有渠道或者线下渠道第一层级 合计算上无归属数据**/
        if(qo.getChannel() == null || (qo.getChannel() == StoreChannelEnum.OFFLINE.getChannel() && qo.getLevel() == levelVo.getLevel())){
            dto.getStoreInfoIdList().add(-1);
            dto.getOnLine().add("-1");
        }
        ServiceResponse<Page<BaseSalesDTO>> totalResponse = this.baseSalesApiService.pageBaseSales(dto);
        log.info("totalResponse:{}", JSON.toJSONString(totalResponse));
        this.goDownComponent.parseTotal(totalResponse, vo);
        Integer wgs = storeSearchUtils.isWgs(qo.getUserId(), qo.getEnterpriseId(), qo.getSearchJSON());
        if(qo.getChannel() != null && qo.getChannel() == 1 && qo.getLevel() == levelVo.getLevel() && wgs == 1){
            dto.setCountType(3); //无归属
            dto.setChannel(null);
            dto.getStoreInfoIdList().clear();
            dto.getOnLine().clear();
            dto.getStoreInfoIdList().add(-1);
            dto.getOnLine().add("-1");
            ServiceResponse<Page<BaseSalesDTO>> wgsResponse = this.baseSalesApiService.pageBaseSales(dto);
            log.info("wgsResponse:{}", JSON.toJSONString(wgsResponse));
            this.goDownComponent.parseWgs(wgsResponse, vo);
        }
        return  RestResponse.success(vo);
    }
}
