package com.gic.cloud.web.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.AttentionStoreDTO;
import com.gic.cloud.dto.DataAuthDTO;
import com.gic.cloud.dto.TempStoreConditionDTO;
import com.gic.cloud.service.DataAuthApiService;
import com.gic.cloud.service.StoreAttentionApiService;
import com.gic.cloud.service.TempStoreConditionApiService;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.cloud.web.auth.OnLineAuth;
import com.gic.cloud.web.auth.OnLineStore;
import com.gic.cloud.web.auth.StoreAuth;
import com.gic.cloud.web.constant.StoreChannelEnum;
import com.gic.cloud.web.qo.StoreSearchQo;
import com.gic.cloud.web.vo.LevelVo;
import com.gic.redis.data.util.RedisUtil;
import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreGroupDTO;
import com.gic.store.dto.StoreSearchDTO;
import com.gic.store.service.StoreApiService;
import com.gic.store.service.StoreGroupApiService;
import com.gic.store.service.StoreWidgetApiService;
import com.google.inject.internal.cglib.core.$ClassEmitter;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.reflections.Store;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

@Component
public class StoreSearchUtils {
    private static final Logger log = LogManager.getLogger(StoreSearchUtils.class);
    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private StoreAttentionApiService storeAttentionApiService;
    @Autowired
    private TempStoreConditionApiService tempStoreConditionApiService;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private StoreApiService storeApiService;
    @Autowired
    private StoreGroupApiService storeGroupApiService;
    @Autowired
    private DataAuthApiService dataAuthApiService;

    public Integer isWgs(Integer userId, Integer enterpriseId, String searchJson){
        JSONObject json = JSON.parseObject(searchJson);
        ServiceResponse<DataAuthDTO> response = this.dataAuthApiService.ggetDataAuthByUserId(enterpriseId, userId);
        DataAuthDTO dataAuthDTO = response.getResult() == null ? new DataAuthDTO() : response.getResult();
        StoreSearchQo storeSearchQo = json.getObject(StoreChannelEnum.OFFLINE.getChannel().toString(), StoreSearchQo.class);
        if(storeSearchQo != null){
            return storeSearchQo.getHasWgs() & dataAuthDTO.getNoOwnerStore();
        }
        return 0;
    }

    public static void main(String[] args){
        System.out.println(1&1);
        System.out.println(1&0);
        System.out.println(0&0);
    }

    public List<Integer> storeSearch(Integer userId, Integer enterpriseId, String searchJson){
        String key = "1:" + enterpriseId + ":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        StoreAuth storeAuth = this.dataAuthUtils.getStoreAuth(userId, enterpriseId);
        if(!storeAuth.isHasAuth()){
            ArrayList<Integer> list = new ArrayList<>();
            list.add(0);
            return list;
        }
        List<Integer> resultList = new ArrayList<>();
        if(StringUtils.isNotBlank(searchJson)){
            JSONObject json = JSON.parseObject(searchJson);
            StoreSearchQo storeSearchQo = json.getObject(StoreChannelEnum.OFFLINE.getChannel().toString(), StoreSearchQo.class);
            if(storeSearchQo.getAll() == 1){
                resultList = storeAuth.getStoreInfoIdList();
            }else {
                StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
                storeSearchDTO.setEnterpriseId(enterpriseId);
                storeSearchDTO.setStoreInfoIds(storeSearchQo.getStoreIds());
                storeSearchDTO.setStoreGroupIds(storeSearchQo.getStoreGroupIds());
                storeSearchDTO.setRegionIds(storeSearchQo.getRegion());
                storeSearchDTO.setStoreTypes(storeSearchQo.getStoreType());
                storeSearchDTO.setStoreStatuss(storeSearchQo.getStoreStatus());
                storeSearchDTO.setErpStatuss(storeSearchQo.getErpStatus());
                storeSearchDTO.setStoreTags(storeSearchQo.getStoreTag());
                if(storeSearchQo.getAttentionStore() == 1){
                    List<AttentionStoreDTO> result = this.storeAttentionApiService.pageStoreAttention(userId, enterpriseId, 1, Integer.MAX_VALUE).getResult().getResult();
                    List<Integer> list = result.stream().map(t -> t.getStoreId()).collect(Collectors.toList());
                    String storeInfoIds = StringUtils.join(list, ",");
                    storeSearchDTO.setStoreInfoIds(storeSearchDTO.getStoreInfoIds()+","+ storeInfoIds);
                }
                if(storeSearchQo.getTmpStore() == 0){
                    TempStoreConditionDTO result = this.tempStoreConditionApiService.getTempStoreCondition(enterpriseId).getResult();
                    if(result != null){
                        Integer tempStoreId = result.getStoreWidgetId();
                        List<Integer> tempStoreIdList = this.storeWidgetApiService.listStoreInfoIdByStoreWidgetId(enterpriseId, tempStoreId).getResult();
                        storeSearchDTO.setStoreIdsOfNot(StringUtils.join(tempStoreIdList, ","));
                    }
                }
                ServiceResponse<Page<StoreDTO>> pageServiceResponse = this.storeApiService.listStore(storeSearchDTO, 1, 20000);
                if(pageServiceResponse.isSuccess() && pageServiceResponse.getResult() != null){
                    List<StoreDTO> storeDTOList = pageServiceResponse.getResult().getResult();
                    List<Integer> storeInfoIdList = storeDTOList.stream().map(storeDTO -> storeDTO.getStoreInfoId()).collect(Collectors.toList());
                    if(CollectionUtils.isNotEmpty(storeAuth.getStoreInfoIdList())){
                        resultList = storeInfoIdList.stream().filter(s -> {
                            for (Integer storeInfoId : storeAuth.getStoreInfoIdList()) {
                                if (s.intValue() == storeInfoId.intValue()) {
                                    return true;
                                }
                            }
                            return false;
                        }).collect(Collectors.toList());
                    }
                }
            }
        }else {
            resultList = storeAuth.getStoreInfoIdList();
        }
        if(CollectionUtils.isNotEmpty(resultList)){
            RedisUtil.setCache(key, 1, 10l, TimeUnit.MINUTES);
        }else {
            resultList.add(0);
        }
        return resultList;
    }

    public List<String> onLineStoreSearch(Integer userId, Integer enterpriseId, String searchJson){
        OnLineAuth onlineStoreAuth = this.dataAuthUtils.getOnlineStore(userId, enterpriseId);
        List<String> list = new ArrayList<>();
        if(onlineStoreAuth.isHasAuth()){
            this.getOnlineStoreIds(searchJson, onlineStoreAuth, list, StoreChannelEnum.GICMALL.getChannel(), userId, enterpriseId);
            this.getOnlineStoreIds(searchJson, onlineStoreAuth, list, StoreChannelEnum.WMMALL.getChannel(), userId, enterpriseId);
            this.getOnlineStoreIds(searchJson, onlineStoreAuth, list, StoreChannelEnum.TIANMAO.getChannel(), userId, enterpriseId);
        }else {
            list.add("noauth");
        }
        return list;
    }

    public LevelVo getLevel(Integer userId, Integer enterpriseId, String searchJson){
        LevelVo vo = new LevelVo();
        List<Integer> list = this.storeSearch(userId, enterpriseId, searchJson);
        StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
        storeSearchDTO.setEnterpriseId(enterpriseId);
        storeSearchDTO.setStoreInfoIds(StringUtils.join(list, " "));
        ServiceResponse<Page<StoreDTO>> response = this.storeApiService.listStore(storeSearchDTO, 1, 20000);
        if(!response.isSuccess() && response.getResult() == null){
            return vo;
        }
        List<StoreDTO> result = response.getResult().getResult();
        Map<Integer, Integer> map = new HashMap<>();
        result.forEach(storeDTO -> {
            List<Integer> storeGroupIdList = storeDTO.getStoreGroupIdList();
            if (CollectionUtils.isNotEmpty(storeGroupIdList)) {
                storeGroupIdList.forEach(storeGroupId -> {
                    map.put(storeGroupId, storeGroupId);
                });
            }
        });
        List<StoreGroupDTO> allStoreGroupIdList = this.storeGroupApiService.listStoreGroupByIds(null, enterpriseId).getResult();
        Map<Integer, Integer> levelMap = new HashMap<>();
        allStoreGroupIdList.forEach(storeGroupDTO -> {
            if(map.containsKey(storeGroupDTO.getStoreGroupId())){
                levelMap.put(storeGroupDTO.getGroupLevel(), levelMap.get(storeGroupDTO.getGroupLevel())== null ? 1 : levelMap.get(storeGroupDTO.getGroupLevel())+1);
            }
        });
        int start = 0;
        if(!levelMap.isEmpty()){
            while (true){
                if(start >= levelMap.size()){
                    break;
                }
                if(levelMap.get(start) != null && levelMap.get(start).intValue() > 1){
                    vo.setLevel(start);
                    break;
                }
                start++;
            }
            vo.setMaxLevel(levelMap.size() - 1);
        }
        return vo;
    }

    public Integer getChannel(Integer userId, Integer enterpriseId, String searchJson){
        String offlineKey = "1:" + enterpriseId + ":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        String gicMallKey = "2:" + enterpriseId + ":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        String wmKey = "3:" + enterpriseId + ":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        String tmKey = "4:" + enterpriseId + ":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        int offline = RedisUtil.getCache(offlineKey) == null ? 0 : 1;
        int gicMall = RedisUtil.getCache(gicMallKey) == null ? 0 : 1;
        int wm = RedisUtil.getCache(wmKey) == null ? 0 : 1;
        int tm = RedisUtil.getCache(tmKey) == null ? 0 : 1;
        if((offline + gicMall + wm + tm) > 1){  //多渠道
            return null;
        }else if((offline + gicMall + wm + tm)  == 1){
            if(offline == 1){
                return offline;
            }
            if(gicMall == 1){
                return gicMall;
            }
            if(wm == 1){
                return wm;
            }
            if(tm == 1){
                return tm;
            }
        }
        return null;
    }

    public List<Integer> getChildrenStoreGroupIdList(Integer storeGroupId){
        if(storeGroupId != null){
            List<StoreGroupDTO> result = this.storeGroupApiService.listStoreGroupAndChildren(storeGroupId).getResult();
            if(CollectionUtils.isNotEmpty(result)){
                return result.stream().map(storeGroupDTO -> storeGroupDTO.getStoreGroupId()).collect(Collectors.toList());
            }
        }
        return new ArrayList<>();
    }

    private void getOnlineStoreIds(String searchJson, OnLineAuth onlineStoreAuth, List<String> list, Integer channel, Integer userId, Integer enterpriseId){
        String key = channel + ":" + enterpriseId +":" + userId +":" + (StringUtils.isNotBlank(searchJson) ? searchJson.hashCode() : "searchJSON".hashCode());
        if(StringUtils.isNotBlank(searchJson)){
            StoreSearchQo searchQo = JSON.parseObject(searchJson).getObject(channel.toString(), StoreSearchQo.class);
            log.info("getOnlineStoreIds:{},{}", searchJson, JSON.toJSONString(searchQo));
            if(searchQo != null){
                if(searchQo.getAll() != 1){
                    if(StringUtils.isNotBlank(searchQo.getStoreGroupIds())){
                        RedisUtil.setCache(key, 1, 10l, TimeUnit.MINUTES);
                        list.addAll(Arrays.asList(searchQo.getStoreGroupIds().split(",")));
                    }
                }
            }
        } else {
            onlineStoreAuth.getList().stream().forEach(s -> {
                if(s.getChannel().intValue() == channel.intValue()){
                    if(CollectionUtils.isNotEmpty(s.getStoreIdList())){
                        RedisUtil.setCache(key, 1, 10l, TimeUnit.MINUTES);
                        list.addAll(s.getStoreIdList());
                    }
                }
            });
        }
    }

}
