package com.gic.cloud.web.controller;

import com.alibaba.druid.sql.ast.statement.SQLForeignKeyImpl;
import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.AttentionStoreDTO;
import com.gic.cloud.service.StoreAttentionApiService;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.cloud.web.auth.OnLineAuth;
import com.gic.cloud.web.auth.OnLineStore;
import com.gic.cloud.web.auth.StoreAuth;
import com.gic.cloud.web.constant.StoreChannelEnum;
import com.gic.cloud.web.vo.*;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.WmStoreDTO;
import com.gic.enterprise.service.WmStoreApiService;
import com.gic.mall.share.api.dto.shop.ShopDTO;
import com.gic.mall.share.api.enums.ShopTypeEnum;
import com.gic.mall.share.api.service.ShopApiService;
import com.gic.store.dto.*;
import com.gic.store.service.*;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;

@RestController
public class StoreWidgetController {
    private static final Logger log = LogManager.getLogger(StoreWidgetController.class);

    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private StoreGroupApiService storeGroupApiService;
    @Autowired
    private StoreApiService storeApiService;
    @Autowired
    private StoreDictApiService storeDictApiService;
    @Autowired
    private StoreRegionApiService storeRegionApiService;
    @Autowired
    private StoreTagApiService storeTagApiService;
    @Autowired
    private ShopApiService shopApiService;
    @Autowired
    private WmStoreApiService wmStoreApiService;
    @Autowired
    private StoreAttentionApiService storeAttentionApiService;
    @Autowired
    private StoreSearchUtils storeSearchUtils;

    @RequestMapping("store-widget-index")
    public RestResponse storeWidgetIndex(Integer userId, Integer enterpriseId){
        StoreWidgetIndexVo vo = new StoreWidgetIndexVo();
        StoreAuth storeAuth = dataAuthUtils.getStoreAuth(userId, enterpriseId);
        OnLineAuth onlineStoreAuth = dataAuthUtils.getOnlineStore(userId, enterpriseId);
        List<IndexItemVo> items = new ArrayList<>();
        if(storeAuth.isHasAuth() && onlineStoreAuth.isHasAuth()){  //线上线下多渠道
            IndexItemVo offLine = new IndexItemVo();
            offLine.setId("1");
            offLine.setName("线下零售");
            offLine.setType(1);
            items.add(offLine);
            this.getOnlineItems(onlineStoreAuth, items);
            vo.setType(1);
        } else if(storeAuth.isHasAuth() && !onlineStoreAuth.isHasAuth()){  //线下单渠道
            vo.setType(2);
        } else if(onlineStoreAuth.getList().size() == 1){  //线上单渠道
            vo.setType(3);
            List<OnLineStore> list = onlineStoreAuth.getList();
            OnLineStore onLineStore = list.get(0);
            List<OnLineStoreVo> onLineStoreVos = this.listOnLineStore(onLineStore.getStoreIdList(), onLineStore.getChannel(), enterpriseId);
            if(CollectionUtils.isNotEmpty(onLineStoreVos)){
                for(OnLineStoreVo onLineStoreVo : onLineStoreVos){
                    IndexItemVo indexItemVo = new IndexItemVo();
                    indexItemVo.setId(onLineStoreVo.getId());
                    indexItemVo.setName(onLineStoreVo.getName());
                    indexItemVo.setType(2);
                    items.add(indexItemVo);
                }
            }
        } else {  //线上多渠道
            vo.setType(1);
            this.getOnlineItems(onlineStoreAuth, items);
        }
        vo.setItems(items);
        Page<AttentionStoreDTO> result = this.storeAttentionApiService.pageStoreAttention(userId, enterpriseId, 1, Integer.MAX_VALUE).getResult();
        if(CollectionUtils.isNotEmpty(result.getResult())){
            vo.setAttentionCount(result.getTotalCount());
        }
        return RestResponse.success(vo);
    }


    @RequestMapping("store-group")
    public RestResponse storeGroup(Integer userId, Integer enterpriseId, Integer parentId,
                                   Integer pageNum, Integer pageSize){
        StoreAuth storeAuth = dataAuthUtils.getStoreAuth(userId, enterpriseId);
        List<Integer> storeGroupIdList = new ArrayList<>();
        Map<Integer, StoreGroupVo> map = this.mapStoreGroup(enterpriseId);
        if(storeAuth.getStoreWidgetId() != null) {
            StoreColumnSet storeColumnSet = this.storeWidgetApiService.getStoreColumnSet(enterpriseId, storeAuth.getStoreWidgetId()).getResult();
            Set<Integer> storeGroupId = storeColumnSet.getStoreGroupId();
            storeGroupIdList = new ArrayList<>(storeGroupId);
        }
        Page<StoreGroupDTO> page = this.storeGroupApiService.pageStoreGroupByIds(storeGroupIdList, enterpriseId, parentId, null, pageSize, pageNum).getResult();
        Page<StoreGroupItemsVo> groupVoPage = new Page<>(pageNum, pageSize);
        List<StoreGroupItemsVo> items = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(page.getResult())){
            for(StoreGroupDTO storeGroupDTO : page.getResult()){
                StoreGroupItemsVo itemsVo = new StoreGroupItemsVo();
                itemsVo.setId(storeGroupDTO.getStoreGroupId());
                itemsVo.setName(storeGroupDTO.getStoreGroupName());
                itemsVo.setIdChain(map.get(storeGroupDTO.getStoreGroupId()).getIdChain());
                itemsVo.setNameChain(map.get(storeGroupDTO.getStoreGroupId()).getNameChain());
                List<StoreGroupDTO> result = this.storeGroupApiService.pageStoreGroupByIds(storeGroupIdList, enterpriseId, parentId,null, pageSize, pageNum).getResult().getResult();
                itemsVo.setHasChildren(CollectionUtils.isEmpty(result) ? 0 : 1);
                items.add(itemsVo);
            }
            groupVoPage.setTotalCount(page.getTotalCount());
            groupVoPage.setTotalPage(page.getTotalPage());
        }else {
            StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
            storeSearchDTO.setEnterpriseId(enterpriseId);
            storeSearchDTO.setStoreGroupId(parentId);
            storeSearchDTO.setStoreResource(Long.valueOf(storeAuth.getStoreWidgetId()));
            ServiceResponse<Page<StoreDTO>> response = this.storeApiService.listStore(storeSearchDTO, pageNum, pageSize);
            Map<Integer, AttentionStoreDTO> result = this.storeAttentionApiService.getAllAttenttionStore(userId, enterpriseId).getResult();
            if(CollectionUtils.isNotEmpty(response.getResult().getResult())){
                for(StoreDTO dto : response.getResult().getResult()){
                    StoreGroupItemsVo itemsVo = new StoreGroupItemsVo();
                    itemsVo.setId(dto.getStoreInfoId());
                    itemsVo.setName(dto.getStoreName());
                    itemsVo.setIsStore(1);
                    itemsVo.setIdChain(map.get(dto.getStoreGroupId()).getIdChain() + dto.getStoreInfoId() + "_");
                    itemsVo.setNameChain(map.get(dto.getStoreGroupId()).getNameChain() + dto.getStoreName() + "/");
                    itemsVo.setHasAttention(result.get(dto.getStoreInfoId()) == null ? 0 : 1);
                    items.add(itemsVo);
                }
                groupVoPage.setTotalCount(response.getResult().getTotalCount());
                groupVoPage.setTotalPage(response.getResult().getTotalPage());
            }
        }
        groupVoPage.setResult(items);
        return RestResponse.success(groupVoPage);
    }

    @RequestMapping("store-type")
    public RestResponse storeType(Integer userId, Integer enterpriseId, Integer type){
        StoreAuth storeAuth = dataAuthUtils.getStoreAuth(userId, enterpriseId);
        StoreColumnSet storeColumnSet = null;
        if(storeAuth.getStoreWidgetId() != null){
            storeColumnSet = this.storeWidgetApiService.getStoreColumnSet(enterpriseId, storeAuth.getStoreWidgetId()).getResult();
        }
        if(type == 1){ //门店类型
            if(storeColumnSet != null){
                Set<Integer> storeType = storeColumnSet.getStoreType();
                if(CollectionUtils.isEmpty(storeType)){
                    return RestResponse.success();
                }else {
                    List<StoreTypeVo> storeTypeVos = this.listStoreTypeOrStatus(enterpriseId, new ArrayList<>(storeType), 1);
                    return RestResponse.success(storeTypeVos);
                }
            }else {
                List<StoreTypeVo> storeTypeVos = this.listStoreTypeOrStatus(enterpriseId, null, 1);
                return RestResponse.success(storeTypeVos);
            }
        } else if(type == 2){  //门店状态
            if(storeColumnSet != null){
                Set<Integer> storeType = storeColumnSet.getErpStatus();
                if(CollectionUtils.isEmpty(storeType)){
                    return RestResponse.success();
                }else {
                    List<StoreTypeVo> storeTypeVos = this.listStoreTypeOrStatus(enterpriseId, new ArrayList<>(storeType), 2);
                    return RestResponse.success(storeTypeVos);
                }
            }else {
                List<StoreTypeVo> storeTypeVos = this.listStoreTypeOrStatus(enterpriseId, null, 2);
                return RestResponse.success(storeTypeVos);
            }
        } else if(type == 3){  //门店域
            if(storeColumnSet != null){
                Set<Integer> region = storeColumnSet.getRegion();
                if(CollectionUtils.isEmpty(region)){
                    return RestResponse.success();
                }else {
                    List<StoreTypeVo> storeTypeVos = this.listRegion(enterpriseId, new ArrayList<>(region));
                    return RestResponse.success(storeTypeVos);
                }
            }else {
                List<StoreTypeVo> storeTypeVos = this.listRegion(enterpriseId, null);
                return RestResponse.success(storeTypeVos);
            }
        }else if(type == 4){  //门店标签
            List<StoreTagDTO> result = this.storeTagApiService.listByEnterprise(enterpriseId).getResult();
            List<StoreTypeVo> list = new ArrayList<>();
            if(CollectionUtils.isNotEmpty(result)){
                for(StoreTagDTO storeTagDTO : result){
                    StoreTypeVo storeTypeVo = new StoreTypeVo();
                    storeTypeVo.setId(storeTagDTO.getStoreTagId()+"");
                    storeTypeVo.setName(storeTagDTO.getStoreTagName());
                    list.add(storeTypeVo);
                }
            }
            return RestResponse.success(list);
        }else {
            List<StoreTypeVo> list = new ArrayList<>();
            if(storeColumnSet != null){
                Set<Integer> status = storeColumnSet.getStatus();
                if(CollectionUtils.isEmpty(status)){
                    return RestResponse.success();
                }else {
                    Iterator<Integer> iterator = status.iterator();
                    while (iterator.hasNext()){
                        StoreTypeVo storeTypeVo = new StoreTypeVo();
                        storeTypeVo.setId(iterator.next()+"");
                        if(iterator.next() == 1){
                            storeTypeVo.setName("启用");
                        }else {
                            storeTypeVo.setName("不启用");
                        }
                        list.add(storeTypeVo);
                    }
                }
            }else {
                StoreTypeVo storeTypeVo = new StoreTypeVo();
                storeTypeVo.setId("1");
                storeTypeVo.setName("启用");
                list.add(storeTypeVo);
                StoreTypeVo storeTypeVo1 = new StoreTypeVo();
                storeTypeVo1.setId("2");
                storeTypeVo1.setName("不启用");
                list.add(storeTypeVo1);
            }
            return RestResponse.success(list);
        }
    }

    @RequestMapping("on-store-list")
    public RestResponse onStoreList(Integer userId, Integer enterpriseId, Integer type){
        OnLineAuth onlineStore = this.dataAuthUtils.getOnlineStore(userId, enterpriseId);
        if(onlineStore.isHasAuth()){
            List<OnLineStore> list = onlineStore.getList();
            for(OnLineStore store : list){
                if(type == store.getChannel()){
                    List<OnLineStoreVo> onLineStoreVos = this.listOnLineStore(store.getStoreIdList(), type, enterpriseId);
                    log.info("on-store-list:{}, {}", JSON.toJSONString(onLineStoreVos), JSON.toJSONString(store.getStoreIdList()));
                    return RestResponse.success(onLineStoreVos);
                }
            }
        }
        return RestResponse.success();
    }

    @RequestMapping("store-search")
    public RestResponse storeSearch(Integer userId, Integer enterpriseId, Integer type, String search,
                                    Integer pageNum, Integer pageSize){
        Page<StoreSearchVo> page = new Page<>(pageNum, pageSize);
        Map<Integer, StoreGroupVo> map = this.mapStoreGroup(enterpriseId);
        if(type == 1){ //门店分组
            Page<StoreGroupDTO> result = this.storeGroupApiService.pageStoreGroupByIds(null, enterpriseId, null, search, pageSize, pageNum).getResult();
            page.setTotalPage(result.getTotalPage());
            page.setTotalCount(result.getTotalCount());
            if(CollectionUtils.isNotEmpty(result.getResult())){
                List<StoreSearchVo> storeSearchVoList = new ArrayList<>();
                for(StoreGroupDTO storeGroupDTO : result.getResult()){
                    StoreSearchVo searchVo = new StoreSearchVo();
                    searchVo.setId(storeGroupDTO.getStoreGroupId()+"");
                    searchVo.setName(storeGroupDTO.getStoreGroupName());
                    searchVo.setIdChain(map.get(storeGroupDTO.getStoreGroupId()).getIdChain());
                    searchVo.setNameChain(map.get(storeGroupDTO.getStoreGroupId()).getNameChain());
                    storeSearchVoList.add(searchVo);
                }
                page.setResult(storeSearchVoList);
            }
        }else if(type == 2){  //线下门店
            StoreAuth storeAuth = this.dataAuthUtils.getStoreAuth(userId, enterpriseId);
            if(storeAuth.isHasAuth()){
                StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
                storeSearchDTO.setSearch(search);
                storeSearchDTO.setEnterpriseId(enterpriseId);
                storeSearchDTO.setStoreInfoIds(StringUtils.join(storeAuth.getStoreInfoIdList(), " "));
                Page<StoreDTO> result = this.storeApiService.listStore(storeSearchDTO, pageNum, pageSize).getResult();
                Map<Integer, AttentionStoreDTO> attentionStoreDTOMap = this.storeAttentionApiService.getAllAttenttionStore(userId, enterpriseId).getResult();
                page.setTotalCount(result.getTotalCount());
                page.setTotalPage(result.getTotalPage());
                if(CollectionUtils.isNotEmpty(result.getResult())){
                    List<StoreSearchVo> storeSearchVoList = new ArrayList<>();
                    for(StoreDTO storeDTO : result.getResult()){
                        StoreSearchVo searchVo = new StoreSearchVo();
                        searchVo.setId(storeDTO.getStoreInfoId()+"");
                        searchVo.setName(storeDTO.getStoreName());
                        searchVo.setIdChain((map.get(storeDTO.getStoreGroupId()) != null ? map.get(storeDTO.getStoreGroupId()).getIdChain() : "") + storeDTO.getStoreInfoId()+"_");
                        searchVo.setNameChain((map.get(storeDTO.getStoreGroupId())!= null ? map.get(storeDTO.getStoreGroupId()).getNameChain() : "") + storeDTO.getStoreName() + "/");
                        searchVo.setHasAttention(attentionStoreDTOMap.get(storeDTO.getStoreInfoId()) == null ? 0 : 1);
                        storeSearchVoList.add(searchVo);
                    }
                    page.setResult(storeSearchVoList);
                }
            }
        }else{  //线上店铺
            OnLineAuth onlineStore = this.dataAuthUtils.getOnlineStore(userId, enterpriseId);
            if(onlineStore.isHasAuth()){
                List<StoreSearchVo> list = new ArrayList<>();
                List<OnLineStore> onlineStoreList = onlineStore.getList();
                for(OnLineStore onLineStore : onlineStoreList){
                    if(onLineStore.getChannel() == StoreChannelEnum.GICMALL.getChannel()){
                        List<ShopDTO> result = shopApiService.getAllShopByEnterpriseIdAndName(enterpriseId, search, ShopTypeEnum.MALL_SHOP.getCode()).getResult();
                        if(CollectionUtils.isNotEmpty(result)){
                            for(ShopDTO dto : result){
                                if(onLineStore.getStoreIdList().contains(dto.getId().toString())){
                                    StoreSearchVo storeSearchVo = new StoreSearchVo();
                                    storeSearchVo.setId(dto.getId().toString());
                                    storeSearchVo.setName(dto.getName());
                                    storeSearchVo.setDesc(StoreChannelEnum.GICMALL.getMessage());
                                    storeSearchVo.setIdChain("_" + StoreChannelEnum.GICMALL.getChannel() + "_" + dto.getId() +"_");
                                    storeSearchVo.setNameChain(StoreChannelEnum.GICMALL.getMessage() + "/" + dto.getName());
                                    storeSearchVo.setChannel(StoreChannelEnum.GICMALL.getChannel());
                                    list.add(storeSearchVo);
                                }
                            }
                        }
                    }
                    if(onLineStore.getChannel() == StoreChannelEnum.WMMALL.getChannel()){
                        List<WmStoreDTO> result1 = wmStoreApiService.listWmStore(enterpriseId, search).getResult();
                        if(CollectionUtils.isNotEmpty(result1)){
                            for(WmStoreDTO wmStoreDTO : result1){
                                if(onLineStore.getStoreIdList().contains(wmStoreDTO.getWmStoreId())){
                                    StoreSearchVo storeSearchVo = new StoreSearchVo();
                                    storeSearchVo.setId(wmStoreDTO.getWmStoreId());
                                    storeSearchVo.setName(wmStoreDTO.getWmMainAccount());
                                    storeSearchVo.setDesc(StoreChannelEnum.WMMALL.getMessage());
                                    storeSearchVo.setIdChain("_" + StoreChannelEnum.GICMALL.getChannel() + "_" + wmStoreDTO.getWmStoreId() +"_");
                                    storeSearchVo.setNameChain(StoreChannelEnum.GICMALL.getMessage() + "/" + wmStoreDTO.getWmMainAccount());
                                    storeSearchVo.setChannel(StoreChannelEnum.GICMALL.getChannel());
                                    list.add(storeSearchVo);
                                }
                            }
                        }
                    }
                }
                page.setResult(list);
                page.setTotalCount(list.size());
                page.setTotalPage(1);
            }
        }
        return RestResponse.success(page);
    }

    @RequestMapping("get-store-count")
    public RestResponse getStoreCount(String searchJSON, Integer userId, Integer enterpriseId){
        List<Integer> list = this.storeSearchUtils.storeSearch(userId, enterpriseId, searchJSON);
        List<String> stringList = this.storeSearchUtils.onLineStoreSearch(userId, enterpriseId, searchJSON);
        log.info("getStoreCount:{},{},{},{},{}", searchJSON, userId, enterpriseId, list.size(), stringList.size());
        return RestResponse.success(list.size() + stringList.size());
    }

    private Map<Integer, StoreGroupVo> mapStoreGroup(Integer enterpriseId){
        List<StoreGroupDTO> result = this.storeGroupApiService.listStoreGroupByIds(null, enterpriseId).getResult();
        Map<Integer, StoreGroupVo> map = new HashMap<>();
        if(CollectionUtils.isNotEmpty(result)){
            this.parseStoreGroup(result, map, 0);
        }
        return map;
    }

    private void parseStoreGroup(List<StoreGroupDTO> storeGroupDTOList, Map<Integer, StoreGroupVo> map, Integer storeGroupId){
        for(StoreGroupDTO dto : storeGroupDTOList){
            if(storeGroupId.intValue() == dto.getParentStoreGroupId().intValue()){
                StoreGroupVo vo = new StoreGroupVo();
                vo.setParentId(storeGroupId);
                vo.setStoreGroupId(dto.getStoreGroupId());
                vo.setStoreGroupName(dto.getStoreGroupName());
                vo.setIdChain(map.get(storeGroupId) == null ? "_0_"+dto.getStoreGroupId()+"_" : map.get(storeGroupId).getIdChain()+ dto.getStoreGroupId()+"_");
                vo.setNameChain(map.get(storeGroupId) == null ? dto.getStoreGroupName()+"/" : map.get(storeGroupId).getNameChain()+ dto.getStoreGroupName()+"/");
                map.put(dto.getStoreGroupId(), vo);
                this.parseStoreGroup(storeGroupDTOList, map, dto.getStoreGroupId());
            }
        }
    }

    private List<OnLineStoreVo> listOnLineStore(List<String> storeIdList, Integer type, Integer enterpriseId){
        List<OnLineStoreVo> list = new ArrayList<>();
        if(type == StoreChannelEnum.GICMALL.getChannel()){
            List<ShopDTO> result = shopApiService.getAllShopByEnterpriseIdAndName(enterpriseId, null, ShopTypeEnum.MALL_SHOP.getCode()).getResult();
            if(CollectionUtils.isNotEmpty(result)){
                for(ShopDTO dto : result){
                    log.info("shopId:{}", dto.getId());
                    if(storeIdList.contains(dto.getId().toString())){
                        OnLineStoreVo onLineStoreVo = new OnLineStoreVo();
                        onLineStoreVo.setId(dto.getId()+"");
                        onLineStoreVo.setName(dto.getName());
                        onLineStoreVo.setIdChain("_" + type + "_" + dto.getId()+"_");
                        onLineStoreVo.setNameChain(StoreChannelEnum.GICMALL.getMessage() + "/" + dto.getName());
                        list.add(onLineStoreVo);
                    }
                }
            }
        }else if(type == StoreChannelEnum.WMMALL.getChannel()){
            List<WmStoreDTO> result = wmStoreApiService.listWmStore(enterpriseId).getResult();
            if(CollectionUtils.isNotEmpty(result)){
                for(WmStoreDTO wmStoreDTO : result){
                    if(storeIdList.contains(wmStoreDTO.getWmMallStoreId().toString())){
                        OnLineStoreVo onLineStoreVo = new OnLineStoreVo();
                        onLineStoreVo.setId(wmStoreDTO.getWmStoreId()+"");
                        onLineStoreVo.setName(wmStoreDTO.getWmPidName());
                        onLineStoreVo.setIdChain("_" + type + "_" + wmStoreDTO.getWmStoreId()+"_");
                        onLineStoreVo.setNameChain(StoreChannelEnum.WMMALL.getMessage() + "/" + wmStoreDTO.getWmPidName());
                        list.add(onLineStoreVo);
                    }
                }
            }
        }
        return list;
    }

    private List<StoreTypeVo> listRegion(Integer enterpriseId, List<Integer> exists){
        List<StoreTypeVo> list = new ArrayList<>();
        List<StoreRegionDTO> result = this.storeRegionApiService.listStoreRegion(enterpriseId, null).getResult();
        for(StoreRegionDTO dto : result){
            StoreTypeVo storeTypeVo = new StoreTypeVo();
            if(CollectionUtils.isNotEmpty(exists)){
                if(exists.contains(dto.getRegionId())){
                    storeTypeVo.setId(dto.getRegionId()+"");
                    storeTypeVo.setName(dto.getRegionName());
                    list.add(storeTypeVo);
                }
            }else {
                storeTypeVo.setId(dto.getRegionId()+"");
                storeTypeVo.setName(dto.getRegionName());
                list.add(storeTypeVo);
            }
        }
        return list;
    }

    private List<StoreTypeVo> listStoreTypeOrStatus(Integer enterpriseId, List<Integer> exists, int type){
        List<StoreDictDTO> result = null;
        if(type == 1){
            result = this.storeDictApiService.listStoreType(enterpriseId).getResult();
        }else {
            result = this.storeDictApiService.listStoreStatus(enterpriseId).getResult();
        }
        List<StoreTypeVo> list = new ArrayList<>();
        for(StoreDictDTO dictDTO : result){
            StoreTypeVo storeTypeVo = new StoreTypeVo();
            if(CollectionUtils.isNotEmpty(exists)){
                if(exists.contains(Integer.valueOf(dictDTO.getValue()))){
                    storeTypeVo.setId(dictDTO.getValue());
                    storeTypeVo.setName(dictDTO.getKey());
                    list.add(storeTypeVo);
                }
            }else {
                storeTypeVo.setId(dictDTO.getValue());
                storeTypeVo.setName(dictDTO.getKey());
                list.add(storeTypeVo);
            }
        }
        return list;
    }

    private String getChannelName(Integer channel){
        StoreChannelEnum[] values = StoreChannelEnum.values();
        for(StoreChannelEnum storeChannelEnum : values){
            if(channel == storeChannelEnum.getChannel()){
                return storeChannelEnum.getMessage();
            }
        }
        return "";
    }

    private void getOnlineItems(OnLineAuth onlineStoreAuth, List<IndexItemVo> items){
        for(OnLineStore onLineStore : onlineStoreAuth.getList()){
            IndexItemVo onLine = new IndexItemVo();
            onLine.setId(onLineStore.getChannel()+"");
            onLine.setName(this.getChannelName(onLineStore.getChannel()));
            onLine.setType(2);
            items.add(onLine);
        }
    }
}
